<?php


namespace SuperRhino\Utils\Auth;


class Auth {

    const AUTH_KEY = 'auth';
    const AUTH_TYPE_JWT = 'jwt';

    //认证方式
    const AUTH_WAY_PWD = 'pwd';
    const AUTH_WAY_OPEN = 'open';


    const SCENE_APP = 'app';
    const SCENE_WEB = 'web';
    const SCENE_ADMIN = 'admin';

    protected string $userId;

    protected string $authType = self::AUTH_TYPE_JWT;

    protected string $scene = self::SCENE_APP;
    protected string $authWay = '';

    /**
     * @return string
     */
    public function getUserId(): string {
        return $this->userId;
    }

    public static function createJwtAuth(string $userId, string $authWay = '', string $scene = self::SCENE_APP): Auth {
        $auth = new self();
        $auth->authType = self::AUTH_TYPE_JWT;
        $auth->scene = $scene;
        $auth->userId = $userId;
        $auth->authWay = $authWay;
        return $auth;
    }

    public static function createAuthByJwtClaims(array $claims, string $scene): Auth {
        $auth = new self();
        $auth->authType = self::AUTH_TYPE_JWT;
        $auth->scene = $scene;
        $auth->userId = $claims['user_id'] ?? '';
        $auth->authWay = $claims['auth_way'] ?? '';
        return $auth;
    }

    /**
     * @return string
     */
    public function getScene(): string {
        return $this->scene;
    }

    public function getAuthClaims(): array {
        return [
            'user_id' => $this->userId,
            'auth_way' => $this->authWay,
        ];
    }
}