<?php


namespace SuperRhino\Utils\Auth;

use Phper666\JWTAuth\JWT;
use Phper666\JWTAuth\Util\JWTUtil;
use Psr\Http\Message\ServerRequestInterface;

class AuthUtil {
    private JWT $jwt;

    /**
     * AuthService constructor.
     * @param JWT $jwt
     */
    public function __construct(JWT $jwt) {
        $this->jwt = $jwt;
    }

    public function getAuthData(Auth $auth): array {
        $token = $this->jwt->getToken($auth->getScene(), $auth->getAuthClaims());
        return [
            'access_token' => $token->toString(),
            'expires_in' => $this->jwt->getTTL($token->toString()),
        ];
    }

    public function handleAuth(ServerRequestInterface $request, string $scene): ?Auth {
        $token = $request->getHeaderLine('Authorization') ?? '';
        if ($token != "") {
            $token = JWTUtil::handleToken($token);
            if ($token !== false && $this->jwt->verifyTokenAndScene($scene, $token)) {
                $tokenClaims = JWTUtil::getParser()->parse($token)->claims()->all();
                return Auth::createAuthByJwtClaims($tokenClaims, $scene);
            }
        }
        return null;
    }

    public function getSceneByToken(string $token) {
        return $this->jwt->getSceneByToken($token);
    }

    public function refreshAuth(): array {
        $token = $this->jwt->refreshToken();
        return [
            'access_token' => $token->toString(),
            'expires_in' => $this->jwt->getTTL($token->toString()),
        ];
    }

    public function hashPassword(string $password): bool|string {
        return password_hash($password, PASSWORD_DEFAULT);
    }

    public function checkPassword(string $password, string $hashedPassword): bool {
        return password_verify(password_hash($password, PASSWORD_DEFAULT), $hashedPassword);
    }
}