<?php


namespace SuperRhino\Utils\Common;


use SuperRhino\Utils\GuzzleClient\GuzzleClient;
use SuperRhino\Utils\Logger\Log;


class CommonRequest {

    public static function send(string $url, string $method, string $api, array $param, array $headers = [], $contentType = 'json') {

        $options = [
            "base_uri" => $url,
        ];

        $sendOptions = [
            "headers" => $headers,
        ];

        $method = strtoupper($method);
        if ($method == 'POST') {
            if ($contentType == 'json') {
                $sendOptions['json'] = $param;
            } elseif ($contentType == 'form') {
                $sendOptions['form_params'] = $param;
            }
        } elseif ($method == 'GET') {
            $sendOptions['query'] = $param;
        }

        $client = GuzzleClient::create($options);
        try {
            $response = $client->request($method, $api, $sendOptions);
        } catch (\Exception $e) {
            Log::error('CommonRequest error', ['error' => $e->getMessage()]);
            return "";
        }

        return $response->getBody();
    }

    public static function sendRaw(string $url, string $api, string $raw, array $headers = []) {
        $options = [
            "base_uri" => $url,
        ];
        $sendOptions = [
            "headers" => $headers,
            "body" => $raw,
        ];
        $client = GuzzleClient::create($options);
        try {
            $response = $client->request('POST', $api, $sendOptions);
        } catch (\Exception $e) {
            Log::error('CommonRequest error', ['error' => $e->getMessage()]);
            return "";
        }
        return $response->getBody();
    }

}