<?php

namespace SuperRhino\Utils\KeyStore;

use SuperRhino\Utils\Cache;
use SuperRhino\Utils\Facade;

class KeyStoreCountAdapter implements KeyStoreCountInterface {

    const CACHE_PREFIX = 'ksc';

    /**
     * @var KeyStoreCountInterface
     */
    private $dbAdapter;

    public function __construct() {
        $keyStoreDbAdapter = Facade::getContainer()->get(KeyStoreDbAdapterInterface::class);
        $this->dbAdapter = $keyStoreDbAdapter->getCountAdapter();
    }

    public function getCount(string $key, int $default = 0): int {
        $cacheKey = $this->getCacheKey($key);
        return Cache::getCallback($cacheKey, function () use ($key, $default) {
            return $this->dbAdapter->getCount($key, $default);
        }, 60 * 60);
    }

    public function setCount(string $key, int $count): bool {
        $cacheKey = $this->getCacheKey($key);
        if ($result = $this->dbAdapter->setCount($key, $count)) {
            Cache::delete($cacheKey);
        }
        return $result;
    }

    public function incrementCount(string $key, int $increment = 1): int {
        $result = $this->dbAdapter->incrementCount($key, $increment);
        Cache::delete($this->getCacheKey($key));
        return $result;
    }

    public function delCount(string $key): bool {
        $this->dbAdapter->delCount($key);
        Cache::delete($this->getCacheKey($key));
        return true;
    }

    private function getCacheKey(string $key): string {
        return self::CACHE_PREFIX . ':' . $key;
    }
}